#!/bin/sh
# script to generate tarball fro upstream git
set -e
giturl='https://github.com/trelau/SMESH.git'
cwd=$(pwd)
tmpdir=$(mktemp -d)
if [ -n "$1" ]
then
    version="v${1#v*}"
else
    version='master'
fi
cd $tmpdir
git clone "$giturl"
cd SMESH
git checkout $version
git submodule update --init --recursive

sed -i -e 's/^import patch$/import patch_ng as patch/g' prepare.py
python3 prepare.py

git add src/*
git commit src/* -m "Add submodules"

git config tar.tar.xz.command "xz -c"
git archive --format=tar.xz -o SMESH-${version#v*}.tar.xz --prefix=SMESH-${version#v*}/ HEAD

for file in *.tar.xz
do
    if [ -e "$cwd/$file" ]
    then
        echo "File already exists, backing up the old one as $cwd/$file.bak" >&2
        mv -f "$cwd/$file" "$cwd/$file.bak"
    fi
    mv "$file" "$cwd/$file"
    echo "----> $file"
done
cd "$cwd"
rm -Rf "$tmpdir"
