%bcond_without test
%bcond_with netgen

%define major     9.8
%define libname   %mklibname smesh %{major}
%define develname %mklibname smesh -d

Name:           smesh
Version:        9.8.0.2
Release:        %mkrel 5
Summary:        OpenCascade based MESH framework
Group:          Graphics/3D

# This library is LGPLv2 with exceptions but links against the non-free library OCE.
License:        LGPLv2
URL:            https://github.com/trelau/SMESH
# Upstream sources doesn't include submodules (use version downloaded with submodules)
#Source0:        https://github.com/trelau/SMESH/archive/v%%{version}/SMESH-%%{version}.tar.gz
Source0:	SMESH-%{version}.tar.xz
# Usage:
# ./gettarball.sh <version>
Source1:	gettarball.sh

Patch1:         0001-CMake-fixes-for-linux-distros.patch

Patch10:	0001-Add-SOVERSION-to-libs.patch
# Fix build with GCC 12: https://github.com/trelau/SMESH/issues/57
Patch11:	smesh-fix-build-with-gcc12.patch

ExcludeArch:    %{arm} %{ix86}
BuildRequires:  cmake gcc-c++ ninja
BuildRequires:  doxygen graphviz
BuildRequires:  boost-devel
#BuildRequires:  catch-devel
BuildRequires:  opencascade-devel
BuildRequires:  vtk-devel
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xi)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	eigen3-devel

%if %{with netgen}
# Dependencies for optional NETGENPlugin library.
BuildRequires:  netgen-mesher-devel
BuildRequires:  netgen-mesher-devel-private
%endif

%description
A complete OpenCascade based MESH framework.

%package -n %{libname}
Summary:        OpenCascade based MESH framework

%description -n %{libname}
A complete OpenCascade based MESH framework.

%package -n %{develname}
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files and headers for %{name}.

%prep
%autosetup -p1 -n SMESH-%{version}

%build
%cmake -GNinja \
       -DENABLE_NETGEN=ON \
       -DNEW_NETGEN_INTERFACE=ON \
       -DENABLE_MED=OFF \
       -DBUILD_TESTS=TRUE

%cmake_build


%install
%cmake_install

%if %{with test}
%check
%ctest
%endif

%files -n %{libname}
%license LICENSE.txt
%doc README.md
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/smesh/
%{_libdir}/*.so
%{_libdir}/cmake/*.cmake


%changelog
* Fri Jan 12 2024 wally <wally> 9.8.0.2-5.mga10
+ Revision: 2030595
- rebuild for boost 1.84.0

* Tue Oct 10 2023 wally <wally> 9.8.0.2-4.mga10
+ Revision: 1994137
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 9.8.0.2-3.mga9
+ Revision: 1926530
- rebuild for boost 1.81.0

* Thu Nov 17 2022 ghibo <ghibo> 9.8.0.2-2.mga9
+ Revision: 1908506
- Exclude unsupported Arch
- Bump release for rebuilding
- Exclude arm build because of unsupported CPU architecture in the sources
- Update to release 9.8.0.2 to fix building against opencascade 7.6.x.
- Rework Patch10.

* Sun Jul 03 2022 wally <wally> 9.7.0.1-4.mga9
+ Revision: 1867311
- rebuild for boost 1.79.0

* Thu Jun 09 2022 papoteur <papoteur> 9.7.0.1-3.mga9
+ Revision: 1863724
- Fix build with GCC 12
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Dec 23 2021 wally <wally> 9.7.0.1-1.mga9
+ Revision: 1763482
- new version 9.7.0.1
- BR Qt5OpenGL
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 8.3.0.4-3.mga9
+ Revision: 1744627
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 8.3.0.4-2.mga9
+ Revision: 1723018
- rebuild for boost 1.76.0

* Wed Mar 03 2021 daviddavid <daviddavid> 8.3.0.4-1.mga9
+ Revision: 1696955
- new version: 8.3.0.4

* Thu Dec 31 2020 wally <wally> 8.3.0.3-3.mga8
+ Revision: 1666817
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 8.3.0.3-2.mga8
+ Revision: 1662059
- rebuild for boost 1.74.0

* Wed Nov 04 2020 joequant <joequant> 8.3.0.3-1.mga8
+ Revision: 1642682
- fix deps
- add deps
- fix build
+ daviddavid <daviddavid>
- new version: 8.3.0.3
- now libmajor is 8.3
- switch to opencascade
+ akien <akien>
- Rebuild against opencascade 7.4.0p1

* Fri Aug 21 2020 joequant <joequant> 6.7.6-4.mga8
+ Revision: 1617518
- build gcc10

* Fri Feb 14 2020 umeabot <umeabot> 6.7.6-3.mga8
+ Revision: 1517069
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 23 2018 umeabot <umeabot> 6.7.6-2.mga7
+ Revision: 1301077
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 daviddavid <daviddavid> 6.7.6-1.mga7
+ Revision: 1237622
- new version: 6.7.6

* Thu Jan 11 2018 wally <wally> 6.7.5-2.mga7
+ Revision: 1192387
- fix requires

* Wed Jan 10 2018 wally <wally> 6.7.5-1.mga7
+ Revision: 1192124
- drop main pkg shipping only license file
- new lib major 3
- disable tests for now
- fix BRs
- clean cmake call and use mga LDFLAGS
+ tv <tv>
- use std make macro
- new release 6.7.5
- rebuild for new libgfortran

* Sun Oct 16 2016 tv <tv> 5.1.2.2-7.mga6
+ Revision: 1061024
- switch to %%autosetup (mga#15579)

* Tue Feb 09 2016 umeabot <umeabot> 5.1.2.2-6.mga6
+ Revision: 952018
- Mageia 6 Mass Rebuild

* Tue Jan 13 2015 shlomif <shlomif> 5.1.2.2-5.mga5
+ Revision: 810335
- Importing smesh (thanks to Richard Houser)


* Sat Jan 10 2015 Richard Houser <rick@divinesymphony.net> - 5.1.2.2-5
- Initial Mageia package (prior work done by Pete Wallace and the Mageia Russian Community)
